/* A Bison parser, made by GNU Bison 1.875.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     IDENTIFIER = 258,
     SYMBOL = 259,
     ARRAY_SYMBOL = 260,
     TYPE_FLOAT = 261,
     TYPE_POINT = 262,
     TYPE_STRING = 263,
     TYPE_COLOR = 264,
     TYPE_NORMAL = 265,
     TYPE_VECTOR = 266,
     TYPE_VOID = 267,
     TYPE_MATRIX = 268,
     TYPE_UNIFORM = 269,
     TYPE_VARYING = 270,
     SHADER_TYPE_SURFACE = 271,
     SHADER_TYPE_VOLUME = 272,
     SHADER_TYPE_IMAGER = 273,
     SHADER_TYPE_TRANSFORMATION = 274,
     SHADER_TYPE_DISPLACEMENT = 275,
     SHADER_TYPE_LIGHT = 276,
     SHADER_TYPE_ATMOSPHERE = 277,
     ATTRIBUTE = 278,
     OPTION = 279,
     RENDERERINFO = 280,
     INCIDENT = 281,
     OPPOSITE = 282,
     LIGHTSOURCE = 283,
     EXTERN = 284,
     TEXTUREINFO = 285,
     OUTPUT = 286,
     IF = 287,
     ELSE = 288,
     WHILE = 289,
     FOR = 290,
     CONTINUE = 291,
     BREAK = 292,
     RETURN = 293,
     ILLUMINATE = 294,
     ILLUMINANCE = 295,
     SOLAR = 296,
     TEXTUREMAP = 297,
     ENVIRONMENT = 298,
     BUMP = 299,
     SHADOW = 300,
     OCCLUSION = 301,
     SETXCOMP = 302,
     SETYCOMP = 303,
     SETZCOMP = 304,
     SETCOMP = 305,
     DIV_ASSIGN = 306,
     MUL_ASSIGN = 307,
     SUB_ASSIGN = 308,
     ADD_ASSIGN = 309,
     OR_OP = 310,
     AND_OP = 311,
     NE_OP = 312,
     EQ_OP = 313,
     LE_OP = 314,
     GE_OP = 315,
     NEG = 316,
     FLOAT_CONSTANT = 317,
     STRING_LITERAL = 318
   };
#endif
#define IDENTIFIER 258
#define SYMBOL 259
#define ARRAY_SYMBOL 260
#define TYPE_FLOAT 261
#define TYPE_POINT 262
#define TYPE_STRING 263
#define TYPE_COLOR 264
#define TYPE_NORMAL 265
#define TYPE_VECTOR 266
#define TYPE_VOID 267
#define TYPE_MATRIX 268
#define TYPE_UNIFORM 269
#define TYPE_VARYING 270
#define SHADER_TYPE_SURFACE 271
#define SHADER_TYPE_VOLUME 272
#define SHADER_TYPE_IMAGER 273
#define SHADER_TYPE_TRANSFORMATION 274
#define SHADER_TYPE_DISPLACEMENT 275
#define SHADER_TYPE_LIGHT 276
#define SHADER_TYPE_ATMOSPHERE 277
#define ATTRIBUTE 278
#define OPTION 279
#define RENDERERINFO 280
#define INCIDENT 281
#define OPPOSITE 282
#define LIGHTSOURCE 283
#define EXTERN 284
#define TEXTUREINFO 285
#define OUTPUT 286
#define IF 287
#define ELSE 288
#define WHILE 289
#define FOR 290
#define CONTINUE 291
#define BREAK 292
#define RETURN 293
#define ILLUMINATE 294
#define ILLUMINANCE 295
#define SOLAR 296
#define TEXTUREMAP 297
#define ENVIRONMENT 298
#define BUMP 299
#define SHADOW 300
#define OCCLUSION 301
#define SETXCOMP 302
#define SETYCOMP 303
#define SETZCOMP 304
#define SETCOMP 305
#define DIV_ASSIGN 306
#define MUL_ASSIGN 307
#define SUB_ASSIGN 308
#define ADD_ASSIGN 309
#define OR_OP 310
#define AND_OP 311
#define NE_OP 312
#define EQ_OP 313
#define LE_OP 314
#define GE_OP 315
#define NEG 316
#define FLOAT_CONSTANT 317
#define STRING_LITERAL 318




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 60 "parser.yxx"
typedef union YYSTYPE {
	CqParseNode::Pos m_Pos;
	CqParseNode*	m_pParseNode;
	TqInt			m_VarType;
	EqShaderType	m_ShaderType;
	TqFloat			m_FloatConst;
	CqString*	m_Identifier;
	struct{
		SqVarRef		VarRef;
		SqFuncRef		FuncRef;
		TqInt				eType;
	}				m_pSymbol;
	struct{
		TqInt				Type;
		CqString*	Space;
	}				m_TypeAndSpace;
	EqCommType		m_CommType;
} YYSTYPE;
/* Line 1240 of yacc.c.  */
#line 181 "parser.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;



